@@ -10,6 +10,14 @@ __all__ = ("Router",)
 
 
 class Router:
+    """Collection of routes with shared configuration and authentication.
+
+    Description:
+        Groups related routes together with common settings like URL prefix,
+        tags, authentication requirements, and dependencies, then creates a
+        configured FastAPI APIRouter instance.
+    """
+
     def __init__(
         self,
         prefix: str = "",
@@ -22,7 +30,27 @@ class Router:
         include_in_schema: bool = True,
         deprecated: bool = False,
     ):
-        """Initialize a Router instance and create the APIRouter."""
+        """Initialize a Router instance and create the APIRouter.
+
+        Description:
+            Configures a router with shared settings and routes, converting
+            authentication requirements into dependencies and creating the
+            underlying FastAPI APIRouter.
+
+        Args:
+            prefix: URL prefix for all routes in this router (e.g., "/api/v1").
+            tags: List of tags for grouping routes in OpenAPI documentation.
+            authentications: List of Auth configurations applied to all routes.
+            dependencies: Additional FastAPI dependencies for all routes.
+            routes: List of Route objects to include in this router.
+            responses: Common response definitions for OpenAPI schema.
+            default_response_class: Default response class for all routes.
+            include_in_schema: If False, excludes all routes from OpenAPI schema.
+            deprecated: If True, marks all routes as deprecated in OpenAPI.
+
+        Returns:
+            None
+        """
 
         dependencies = dependencies or []
         for authentication in authentications or []:
@@ -40,7 +68,18 @@ class Router:
         self.router = self._create_router()
 
     def _create_router(self) -> APIRouter:
-        """Create an APIRouter dynamically based on the configuration."""
+        """Create an APIRouter dynamically based on the configuration.
+
+        Description:
+            Builds a FastAPI APIRouter with configured settings and registers
+            all routes with their individual configurations.
+
+        Args:
+            None
+
+        Returns:
+            APIRouter: Configured FastAPI router ready to be included in an application.
+        """
 
         router = APIRouter(
             prefix=self.prefix,
@@ -78,5 +117,16 @@ class Router:
         return router
 
     def get_router(self) -> APIRouter:
-        """Return the underlying :class:`APIRouter` instance."""
+        """Return the underlying APIRouter instance.
+
+        Description:
+            Retrieves the configured FastAPI APIRouter for inclusion in an
+            Application or another router.
+
+        Args:
+            None
+
+        Returns:
+            APIRouter: The configured FastAPI APIRouter instance.
+        """
         return self.router
