@@ -8,11 +8,18 @@ __all__ = ("hash_data",)
 
 
 def serialize_data(data: Any) -> bytes:
-    """Serializes data into a bytes object.
+    """Serialize data into a bytes object for hashing.
 
-    - If data is a string, encode it directly.
-    - If data is a dictionary, use JSON with sorted keys for consistency.
-    - Otherwise, try JSON serialization; if that fails, use repr().
+    Description:
+        Converts various data types into a consistent byte representation
+        suitable for hashing. Handles strings, dictionaries, and other
+        JSON-serializable types with fallback to repr().
+
+    Args:
+        data: The data to serialize. Can be str, dict, list, tuple, or other types.
+
+    Returns:
+        The serialized data as bytes.
     """
     if isinstance(data, str):
         return data.encode("utf-8")
@@ -27,14 +34,23 @@ def serialize_data(data: Any) -> bytes:
 
 
 def hash_data(data: Any, algorithm: str = "sha512") -> str:
-    """Hashes the provided data using the specified algorithm.
+    """Hash the provided data using the specified algorithm.
 
-    Supported algorithms:
-    - md5: 32 hex characters
-    - sha1: 40 hex characters
-    - sha256: 64 hex characters
-    - blake2b: Customizable; here set to 16 bytes (32 hex characters)
-    - blake2s: Customizable; here set to 16 bytes (32 hex characters)
+    Description:
+        Serializes the input data and generates a cryptographic hash using
+        one of the supported algorithms. Default algorithm is SHA-512.
+
+    Args:
+        data: The data to hash. Can be any serializable type.
+        algorithm: The hashing algorithm to use. Supported values:
+            'md5', 'sha1', 'sha256', 'sha512', 'blake2b', 'blake2s'.
+            Defaults to 'sha512'.
+
+    Returns:
+        The hexadecimal string representation of the hash digest.
+
+    Raises:
+        ValueError: If an unsupported algorithm is specified.
     """
     serialized = serialize_data(data)
 
