@@ -10,13 +10,13 @@ from contextlib import asynccontextmanager, contextmanager
 from typing import Any, AsyncGenerator, Generator, Optional
 
 from sqlalchemy import NullPool, create_engine, text
-from sqlalchemy.ext.asyncio import (AsyncSession, async_sessionmaker,
-                                    create_async_engine)
+from sqlalchemy.ext.asyncio import AsyncSession, async_sessionmaker, create_async_engine
+from sqlalchemy.orm import Session as SessionType
 from sqlalchemy.orm import declarative_base, sessionmaker
 
 from ..core.exception import exception_to_dict
-from ..log import footprint
 from .config import DatabaseConfig
+from ..log import footprint
 
 __all__ = ("DatabaseInstance",)
 
@@ -24,14 +24,22 @@ __all__ = ("DatabaseInstance",)
 class DatabaseInstance:
     """Manage SQLAlchemy engines and sessions for read/write usage.
 
-    Parameters
-    ----------
-    config:
-        Resolved database configuration holding credentials and connection
-        options for read and write connections.
+    This class orchestrates database connections providing both synchronous
+    and asynchronous engines, session factories, and context managers for
+    read and write operations. It supports connection pooling, SSL configuration,
+    and separate read replicas.
+
+    Args:
+        config: Resolved database configuration holding credentials and connection
+            options for read and write connections.
     """
 
     def __init__(self, config: DatabaseConfig) -> None:
+        """Initialize DatabaseInstance with configuration settings.
+
+        Args:
+            config: DatabaseConfig instance containing all connection parameters.
+        """
         self.db_backend = (config.get("db_backend") or "postgresql").lower()
         self.db_driver_sync = config.get("db_driver_sync")
         self.db_driver_async = config.get("db_driver_async")
@@ -120,6 +128,17 @@ class DatabaseInstance:
         self.base = declarative_base(name="Base")
 
     def _build_async_url(self, db_url: str) -> str:
+        """Convert a standard database URL to its asynchronous equivalent.
+
+        This method adapts the URL scheme for async drivers, particularly for
+        PostgreSQL, by replacing driver names and adjusting SSL parameters.
+
+        Args:
+            db_url: The synchronous database URL.
+
+        Returns:
+            The asynchronous database URL.
+        """
         if self.db_driver_sync:
             if self.db_driver_async:
                 db_url = db_url.replace(
@@ -149,6 +168,19 @@ class DatabaseInstance:
     def _build_database_url(
         self, async_mode: bool = False, host: Optional[str] = None
     ) -> str:
+        """Construct a database URL from configuration components.
+
+        Builds a properly formatted database connection URL from individual
+        configuration parameters, supporting both sync and async drivers
+        with optional SSL settings.
+
+        Args:
+            async_mode: If True, build an async URL; otherwise, a sync URL.
+            host: The database host. Defaults to the write host if None.
+
+        Returns:
+            The fully constructed database connection URL string.
+        """
         if host is None:
             host = self.db_host_write
 
@@ -171,7 +203,15 @@ class DatabaseInstance:
         return url
 
     def _initialize_db_settings(self) -> dict:
-        """Build engine keyword arguments based on pooling configuration."""
+        """Build engine keyword arguments based on pooling configuration.
+
+        Constructs SQLAlchemy engine settings including connection pooling,
+        SSL configuration, and connection arguments based on the database
+        backend and configuration.
+
+        Returns:
+            Dictionary of SQLAlchemy engine keyword arguments.
+        """
         settings: dict[str, Any] = {
             "pool_pre_ping": True,
             "echo": False,
@@ -196,21 +236,38 @@ class DatabaseInstance:
 
         return settings
 
-    def session_local(self):
-        """Create a new synchronous write session."""
+    def session_local(self) -> SessionType:
+        """Create a new synchronous write session.
+
+        Returns:
+            A new SQLAlchemy Session instance configured for write operations.
+        """
         return self.write_session()
 
-    def session_local_read(self):
-        """Create a new synchronous read session."""
+    def session_local_read(self) -> SessionType:
+        """Create a new synchronous read session.
+
+        Returns:
+            A new SQLAlchemy Session instance configured for read-only operations.
+        """
         return self.read_session()
 
-    def get_db(self, force: Optional[str] = None) -> Generator:
-        """Yield a sync session, handling rollback and close on errors.
+    def get_db(self, force: Optional[str] = None) -> Generator[SessionType, None, None]:
+        """Yield a synchronous database session.
 
-        Parameters
-        ----------
-        force:
-            If "read" yields a read-only session; otherwise a write session.
+        This generator provides a session and ensures it is properly closed
+        after use. It will roll back the session if an exception occurs during
+        the session lifecycle.
+
+        Args:
+            force: If "read", yields a read-only session; otherwise, a write session.
+
+        Yields:
+            A SQLAlchemy Session object for database operations.
+
+        Raises:
+            Exception: Re-raises any exception that occurs during session usage
+                after rolling back the transaction.
         """
         controller = f"{__name__}.get_db"
         if force == "read":
@@ -236,8 +293,23 @@ class DatabaseInstance:
                 )
 
     @contextmanager
-    def get_db_cm(self, force: Optional[str] = None):
-        """Context manager variant of ``get_db`` for sync sessions."""
+    def get_db_cm(
+        self, force: Optional[str] = None
+    ) -> Generator[SessionType, None, None]:
+        """Provide a synchronous database session as a context manager.
+
+        Manages the session lifecycle automatically with proper cleanup
+        and rollback on exceptions.
+
+        Args:
+            force: If "read", provides a read-only session; otherwise, a write session.
+
+        Yields:
+            A SQLAlchemy Session object for database operations.
+
+        Raises:
+            Exception: Re-raises any exception after rolling back the transaction.
+        """
         controller = f"{__name__}.get_db_cm"
         if force == "read":
             db = self.session_local_read()
@@ -261,38 +333,79 @@ class DatabaseInstance:
                     payload=exception_to_dict(e),
                 )
 
-    def get_db_read(self) -> Generator:
-        """Yield a synchronous read session."""
+    def get_db_read(self) -> Generator[SessionType, None, None]:
+        """Yield a synchronous read-only database session.
+
+        Convenience method that delegates to get_db with force="read".
+
+        Yields:
+            A SQLAlchemy Session configured for read-only operations.
+        """
         yield from self.get_db(force="read")
 
-    def get_db_write(self) -> Generator:
-        """Yield a synchronous write session."""
+    def get_db_write(self) -> Generator[SessionType, None, None]:
+        """Yield a synchronous write-enabled database session.
+
+        Convenience method that delegates to get_db with force="write".
+
+        Yields:
+            A SQLAlchemy Session configured for write operations.
+        """
         yield from self.get_db(force="write")
 
     @contextmanager
-    def get_db_cm_read(self):
-        """Context manager for a synchronous read session."""
+    def get_db_cm_read(self) -> Generator[SessionType, None, None]:
+        """Provide a synchronous read-only session via a context manager.
+
+        Yields:
+            A SQLAlchemy Session configured for read-only operations.
+        """
         with self.get_db_cm(force="read") as db:
             yield db
 
     @contextmanager
-    def get_db_cm_write(self):
-        """Context manager for a synchronous write session."""
+    def get_db_cm_write(self) -> Generator[SessionType, None, None]:
+        """Provide a synchronous write-enabled session via a context manager.
+
+        Yields:
+            A SQLAlchemy Session configured for write operations.
+        """
         with self.get_db_cm(force="write") as db:
             yield db
 
     def create_tables(self) -> None:
-        """Create tables defined on the declarative base in the write
-        database."""
+        """Create all tables defined on the declarative base.
+
+        This method uses the write engine to create tables in the database
+        based on all models that inherit from the declarative base. This
+        operation is idempotent - existing tables will not be modified.
+
+        Returns:
+            None
+        """
         self.base.metadata.create_all(self.engine_write)
 
     def close_all_connections(self) -> None:
-        """Dispose all engines, closing pooled connections."""
+        """Dispose of all engine connection pools.
+
+        Closes all database connections and cleans up connection pool resources
+        for both read and write engines.
+
+        Returns:
+            None
+        """
         self.engine_write.dispose()
         self.engine_read.dispose()
 
     def check_database_health(self) -> bool:
-        """Ping both write and read databases; return ``True`` if healthy."""
+        """Ping both write and read databases; return True if healthy.
+
+        Executes a simple SELECT 1 query on both write and read database
+        connections to verify they are operational.
+
+        Returns:
+            True if both databases respond successfully, False otherwise.
+        """
         controller = f"{__name__}.check_database_health"
         try:
             with self.engine_write.connect() as connection:
@@ -312,17 +425,38 @@ class DatabaseInstance:
             return False
 
     def async_session_local(self) -> AsyncSession:
-        """Create a new asynchronous write session."""
+        """Create a new asynchronous write session.
+
+        Returns:
+            A new AsyncSession instance configured for write operations.
+        """
         return self.async_write_session()
 
     def async_session_local_read(self) -> AsyncSession:
-        """Create a new asynchronous read session."""
+        """Create a new asynchronous read session.
+
+        Returns:
+            A new AsyncSession instance configured for read-only operations.
+        """
         return self.async_read_session()
 
     async def async_get_db(
         self, force: Optional[str] = None
     ) -> AsyncGenerator[AsyncSession, None]:
-        """Async generator yielding a session with safe cleanup on errors."""
+        """Async generator yielding a session with safe cleanup on errors.
+
+        Provides an asynchronous database session with automatic rollback
+        on exceptions and guaranteed cleanup.
+
+        Args:
+            force: If "read", yields a read-only session; otherwise, a write session.
+
+        Yields:
+            An AsyncSession object for database operations.
+
+        Raises:
+            Exception: Re-raises any exception after rolling back the transaction.
+        """
         controller = f"{__name__}.async_get_db"
         if force == "read":
             db = self.async_session_local_read()
@@ -350,7 +484,20 @@ class DatabaseInstance:
     async def async_get_db_cm(
         self, force: Optional[str] = None
     ) -> AsyncGenerator[AsyncSession, None]:
-        """Async context manager yielding an async session."""
+        """Async context manager yielding an async session.
+
+        Provides an asynchronous database session as a context manager with
+        automatic cleanup and rollback on exceptions.
+
+        Args:
+            force: If "read", provides a read-only session; otherwise, a write session.
+
+        Yields:
+            An AsyncSession object for database operations.
+
+        Raises:
+            Exception: Re-raises any exception after rolling back the transaction.
+        """
         if force == "read":
             db = self.async_session_local_read()
         else:
@@ -365,23 +512,43 @@ class DatabaseInstance:
             await db.close()
 
     async def async_get_db_read(self) -> AsyncGenerator[AsyncSession, None]:
-        """Yield async read sessions from ``async_get_db``."""
+        """Yield async read sessions from async_get_db.
+
+        Convenience method for obtaining read-only asynchronous sessions.
+
+        Yields:
+            An AsyncSession configured for read-only operations.
+        """
         async for db in self.async_get_db(force="read"):
             yield db
 
     async def async_get_db_write(self) -> AsyncGenerator[AsyncSession, None]:
-        """Yield async write sessions from ``async_get_db``."""
+        """Yield async write sessions from async_get_db.
+
+        Convenience method for obtaining write-enabled asynchronous sessions.
+
+        Yields:
+            An AsyncSession configured for write operations.
+        """
         async for db in self.async_get_db(force="write"):
             yield db
 
     @asynccontextmanager
     async def async_get_db_cm_read(self) -> AsyncGenerator[AsyncSession, None]:
-        """Async context manager for a read session."""
+        """Async context manager for a read session.
+
+        Yields:
+            An AsyncSession configured for read-only operations.
+        """
         async with self.async_get_db_cm(force="read") as db:
             yield db
 
     @asynccontextmanager
     async def async_get_db_cm_write(self) -> AsyncGenerator[AsyncSession, None]:
-        """Async context manager for a write session."""
+        """Async context manager for a write session.
+
+        Yields:
+            An AsyncSession configured for write operations.
+        """
         async with self.async_get_db_cm(force="write") as db:
             yield db
