@@ -1,14 +1,38 @@
+"""Base model classes and utilities for SQLAlchemy ORM models.
+
+Provides ModelBase class with common fields, serialization methods, and
+helper functions for tracking model changes.
+"""
+
 import json
 import uuid
+from typing import Any
 
 from sqlalchemy import UUID, Column, DateTime, func, inspect
+from sqlalchemy.orm import Session
 
 from ..core.jsonable_encoder import jsonable_encoder
 
 __all__ = ("ModelBase",)
 
 
-def get_difference_between_dictionaries(old_value, new_value, path=""):
+def get_difference_between_dictionaries(
+    old_value: Any, new_value: Any, path: str = ""
+) -> list[str]:
+    """Recursively find paths that differ between two dictionary/list
+    structures.
+
+    Compares two data structures (dictionaries or lists) and returns a list of
+    paths where differences exist. Useful for tracking changes in nested data.
+
+    Args:
+        old_value: The original data structure to compare.
+        new_value: The new data structure to compare against.
+        path: The current path in the structure (used for recursion).
+
+    Returns:
+        A list of string paths indicating where changes occurred.
+    """
     changes = []
 
     if isinstance(old_value, dict) and isinstance(new_value, dict):
@@ -51,7 +75,19 @@ def get_difference_between_dictionaries(old_value, new_value, path=""):
     return changes
 
 
-def get_modified_keys(instance):
+def get_modified_keys(instance: Any) -> list[str]:
+    """Return the list of attribute keys that have been modified on the
+    instance.
+
+    Uses SQLAlchemy's inspection API to detect which attributes have changed
+    since the instance was loaded from the database or last committed.
+
+    Args:
+        instance: A SQLAlchemy model instance to inspect.
+
+    Returns:
+        A list of attribute key names that have been modified.
+    """
     inst_state = inspect(instance)
     modified_attrs = [
         attr.key for attr in inst_state.attrs if attr.history.has_changes()
@@ -60,6 +96,23 @@ def get_modified_keys(instance):
 
 
 class ModelBase(object):
+    """Base class for SQLAlchemy models with common fields and serialization.
+
+    Provides standard fields (id, created_at, updated_at), serialization methods,
+    and utilities for creating/updating model instances with support for settings
+    fields and change tracking.
+
+    Attributes:
+        id: UUID primary key column.
+        created_at: Timestamp when the record was created.
+        updated_at: Timestamp when the record was last updated.
+        settings: Optional JSON field for storing model-specific settings.
+        regular_settings_field: If True, treats settings as a regular field.
+        combined_settings: If True, merges settings into the main dict during serialization.
+        need_jsonable_encoder: If True, uses jsonable_encoder for data processing.
+        valid_settings: List of valid setting keys allowed for this model.
+    """
+
     id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
 
     created_at = Column(DateTime(timezone=True), server_default=func.now())
@@ -75,12 +128,33 @@ class ModelBase(object):
 
     @classmethod
     def get_fields(cls) -> list:
+        """Return a list of column names excluding 'settings'.
+
+        Returns:
+            List of column names defined on the model's table, excluding 'settings'.
+        """
         fields = list(cls.__table__.columns.keys())
         if "settings" in fields:
             fields.remove("settings")
         return fields
 
-    def get(self, excludes: set = None, includes: set = None) -> dict | None:
+    def get(
+        self, excludes: set[str] | None = None, includes: set[str] | None = None
+    ) -> dict[str, Any] | None:
+        """Serialize the model instance to a dictionary with optional field
+        filtering.
+
+        Converts the model instance to a dictionary representation, optionally
+        merging settings fields and applying inclusion/exclusion filters.
+
+        Args:
+            excludes: Set of field names to exclude from the result.
+            includes: Set of field names to include in the result (if specified,
+                only these fields will be included).
+
+        Returns:
+            Dictionary representation of the model, or None if instance is None.
+        """
         if self is None:
             return
 
@@ -111,7 +185,19 @@ class ModelBase(object):
         return model
 
     @classmethod
-    def create(cls, db, data):
+    def create(cls, db: Session, data: dict[str, Any] | Any) -> "ModelBase":
+        """Create a new model instance and persist it to the database.
+
+        Processes the provided data, separating regular fields from settings,
+        and creates a new database record.
+
+        Args:
+            db: SQLAlchemy session for database operations.
+            data: Dictionary or model containing the data for the new instance.
+
+        Returns:
+            The newly created and persisted model instance.
+        """
         data = jsonable_encoder(data) if cls.need_jsonable_encoder else data
         model_fields = {}
 
@@ -142,7 +228,20 @@ class ModelBase(object):
         db.refresh(new_model)
         return new_model
 
-    def update(self, db, data):
+    def update(self, db: Session, data: dict[str, Any] | Any) -> "ModelBase":
+        """Update the model instance with new data and persist changes.
+
+        Processes the provided data, updates the instance attributes,
+        tracks changes including settings modifications, and commits
+        the changes to the database.
+
+        Args:
+            db: SQLAlchemy session for database operations.
+            data: Dictionary or model containing the updated data.
+
+        Returns:
+            The updated model instance after refresh from database.
+        """
         data = jsonable_encoder(data) if self.need_jsonable_encoder else data
 
         if not self.regular_settings_field:
