@@ -1,10 +1,16 @@
+"""Advanced database search and filtering utilities.
+
+Provides the get_list function for executing complex search queries with
+filtering, pagination, sorting, and metadata generation capabilities.
+"""
+
 from enum import Enum
 from math import ceil
-from typing import Any
+from typing import Any, Type
 
 from sqlalchemy import distinct as distinct_func
 from sqlalchemy import func, select
-from sqlalchemy.orm import Session
+from sqlalchemy.orm import DeclarativeBase, Session
 
 from .search_utils.filter_values import get_filters_value
 from .search_utils.free_search import free_search
@@ -15,27 +21,65 @@ __all__ = ("get_list",)
 
 
 def get_list(
-    current_query: dict,
+    current_query: dict[str, Any],
     db: Session,
-    model: Any,
-    joins: list[dict] = None,
-    pre_conditions: list = None,
-    filters: list = None,
-    searchable_columns: list = None,
+    model: Type[DeclarativeBase],
+    joins: list[dict[str, Any]] | None = None,
+    pre_conditions: list[Any] | None = None,
+    filters: list[dict[str, Any]] | None = None,
+    searchable_columns: list[Any] | None = None,
     exact_search: bool = False,
     search_tokenizer: bool = False,
     search_similarity_threshold: float = 0.1,
-    options: list = None,
+    options: list[Any] | None = None,
     primary_column: str = "id",
     sorting_null_at_the_end: bool = True,
-    get_function_parameters: dict = None,
+    get_function_parameters: dict[str, Any] | None = None,
     return_available_filters: bool = True,
     return_selected_filters: bool = True,
     return_rows_data: bool = True,
     export_mode: bool = False,
     return_as_dict: bool = True,
     unique: bool = True,
-):
+) -> list[Any] | dict[str, Any]:
+    """Execute a complex search query with filters, pagination, and optional
+    metadata.
+
+    Performs advanced database queries with support for filtering, free-text search,
+    pagination, sorting, and result metadata generation. Handles joins, pre-conditions,
+    and various filter types (select, number, date).
+
+    Args:
+        current_query: Dictionary containing search parameters (search text, filters,
+            pagination, sorting).
+        db: SQLAlchemy session for database operations.
+        model: The SQLAlchemy model class to query.
+        joins: List of join configurations for related tables.
+        pre_conditions: List of WHERE conditions to always apply.
+        filters: List of filter definitions for dynamic filtering.
+        searchable_columns: List of columns to include in free-text search.
+        exact_search: If True, use exact phrase matching for searches.
+        search_tokenizer: If True, use full-text search tokenization.
+        search_similarity_threshold: Minimum similarity score for fuzzy matching.
+        options: List of SQLAlchemy query options (e.g., joinedload).
+        primary_column: Name of the primary key column for deduplication.
+        sorting_null_at_the_end: If True, place null values at end when sorting.
+        get_function_parameters: Parameters to pass to model's get() method.
+        return_available_filters: If True, include available filter options in result.
+        return_selected_filters: If True, include selected filters in result.
+        return_rows_data: If True, include actual data rows in result.
+        export_mode: If True, return only rows without metadata.
+        return_as_dict: If True, convert rows to dicts using model's get() method.
+        unique: If True, deduplicate results by primary column.
+
+    Returns:
+        If export_mode is True, returns list of rows.
+        Otherwise, returns dictionary containing:
+            - payload: Query parameters and pagination metadata.
+            - available_filters: Available filter options (if requested).
+            - selected_filters: Currently applied filters (if requested).
+            - rows_data: Matching data rows (if requested).
+    """
     if joins is None:
         joins = []
 
