@@ -1,3 +1,12 @@
+"""Filter value extraction utilities for database searches.
+
+Provides functions to query the database and extract available filter
+options based on actual data, supporting select, number, and date filter
+types.
+"""
+
+from typing import Any
+
 from sqlalchemy import func, union
 from sqlalchemy.orm import Session
 
@@ -5,8 +14,29 @@ __all__ = ("get_filters_value",)
 
 
 def filters_mapper(
-    db: Session, pre_conditions: list, joins: list[dict], filter_item, conditions
-):
+    db: Session,
+    pre_conditions: list[Any],
+    joins: list[dict[str, Any]],
+    filter_item: dict[str, Any],
+    conditions: list[Any],
+) -> list[dict[str, Any]] | dict[str, Any] | None:
+    """Extract unique values from database columns for filter options.
+
+    Queries the database to find all unique values or ranges for a given filter,
+    generating the available options that can be presented to users.
+
+    Args:
+        db: SQLAlchemy session for database queries.
+        pre_conditions: List of base WHERE conditions to apply.
+        joins: List of join configurations for related tables.
+        filter_item: Dictionary defining the filter (type, columns, labels, etc.).
+        conditions: Additional filter conditions to apply.
+
+    Returns:
+        For select filters: List of dicts with 'label' and 'value' keys.
+        For number/date filters: Dict with 'min' and 'max' keys.
+        None if filter type is not supported.
+    """
     columns = filter_item.get("columns")
     columns_type = filter_item.get("type", "select")
 
@@ -67,11 +97,31 @@ def filters_mapper(
 
 def get_filters_value(
     db: Session,
-    pre_conditions: list,
-    joins: list[dict],
-    filters: list,
-    names_conditions: dict,
-):
+    pre_conditions: list[Any],
+    joins: list[dict[str, Any]],
+    filters: list[dict[str, Any]],
+    names_conditions: dict[str, list[Any]],
+) -> list[dict[str, Any]]:
+    """Build a list of available filter options from database data.
+
+    Queries the database for each defined filter to generate the available
+    options based on actual data, applying pre-conditions and cross-filter
+    conditions.
+
+    Args:
+        db: SQLAlchemy session for database queries.
+        pre_conditions: List of base WHERE conditions to always apply.
+        joins: List of join configurations for related tables.
+        filters: List of filter definitions.
+        names_conditions: Dictionary mapping filter names to their conditions.
+
+    Returns:
+        List of available filter dictionaries, each containing:
+            - label: Display label for the filter
+            - name: Internal filter name
+            - type: Filter type (select, number, date, etc.)
+            - value: Available options or range for the filter
+    """
     available_filters = []
     for filter_item in filters:
         filter_name_conditions = names_conditions.get(filter_item["name"])
