@@ -1,3 +1,10 @@
+"""Free-text search condition builder for PostgreSQL.
+
+Provides functions to build WHERE conditions and ORDER BY clauses for
+full-text search using PostgreSQL's text search capabilities and
+similarity functions.
+"""
+
 from typing import Sequence, Tuple
 
 from sqlalchemy import String, Text, cast, desc, func, literal, or_
@@ -14,15 +21,22 @@ def free_search(
 ) -> Tuple[Sequence[ColumnElement], Sequence[UnaryExpression]]:
     """Build WHERE conditions and ORDER BY clauses for a free-text search.
 
-    :param columns: List of SQLAlchemy column expressions to search.
-    :param query: The search string.
-    :param threshold: Similarity threshold for fuzzy matching.
-    :param exact: If True, perform exact or phrase search; otherwise fuzzy.
-    :param tokenize: If True, use full-text search; otherwise simple comparisons.
+    Creates SQL conditions and sorting expressions for searching across multiple
+    columns using PostgreSQL full-text search and similarity functions. Supports
+    exact phrase matching, fuzzy matching, and tokenized search.
 
-    :return: A tuple (conditions, order_by), where:
-        - conditions: SQL boolean expressions for WHERE.
-        - order_by: SQL expressions for ORDER BY.
+    Args:
+        columns: List of SQLAlchemy column expressions to search.
+        query: The search string entered by the user.
+        threshold: Minimum similarity score (0.0-1.0) for fuzzy matching.
+        exact: If True, perform exact phrase matching; otherwise, fuzzy matching.
+        tokenize: If True, use PostgreSQL full-text search; otherwise, use simple
+            string comparison or similarity.
+
+    Returns:
+        A tuple (conditions, order_by) where:
+            - conditions: List of SQL boolean expressions for WHERE clause.
+            - order_by: List of SQL expressions for ORDER BY clause (relevance ranking).
     """
     # Helper: cast query to Text
     txt_query = literal(query).cast(Text)
