@@ -1,14 +1,43 @@
+"""SQL condition builders for various filter types.
+
+Provides functions to construct SQLAlchemy WHERE conditions from filter
+definitions and user-selected values, supporting select, number, and
+date filters.
+"""
+
 from datetime import datetime
 from enum import Enum
 from typing import Any
 
 from sqlalchemy import Text, and_, cast, func, literal, or_, select
-from sqlalchemy.dialects.postgresql import array, ARRAY
+from sqlalchemy.dialects.postgresql import ARRAY, array
+from sqlalchemy.sql.elements import ColumnElement
 
 __all__ = ("make_condition",)
 
 
-def select_condition_maker(filter_item: dict, values: list, array_mode: bool):
+def select_condition_maker(
+    filter_item: dict[str, Any], values: list[Any], array_mode: bool
+) -> ColumnElement[bool]:
+    """Build SQL conditions for select-based filters with optional similarity
+    search.
+
+    Creates WHERE conditions for select-type filters, supporting exact matching,
+    case-insensitive comparison, array operations, and fuzzy similarity matching.
+
+    Args:
+        filter_item: Dictionary defining the filter configuration including:
+            - columns: List of column expressions to filter
+            - columns_logic: 'or' or 'and_' for combining column conditions
+            - case_insensitive: If True, perform case-insensitive matching
+            - use_similarity: If True, use fuzzy similarity matching
+            - similarity_threshold: Minimum similarity score for fuzzy matches
+        values: List of selected values to filter by.
+        array_mode: If True, treat columns as arrays and use array operators.
+
+    Returns:
+        A SQLAlchemy boolean expression combining all filter conditions.
+    """
     columns = filter_item.get("columns", [])
     columns_logic = filter_item.get("columns_logic", "or")
     case_insensitive = filter_item.get("case_insensitive", False)
@@ -72,8 +101,25 @@ def select_condition_maker(filter_item: dict, values: list, array_mode: bool):
     return logic_fn(*conditions)
 
 
-def number_condition_maker(filter_item: dict, values: dict):
-    columns = filter_item.get("columns")
+def number_condition_maker(
+    filter_item: dict[str, Any], values: dict[str, Any]
+) -> ColumnElement[bool] | None:
+    """Build SQL conditions for numeric range filters.
+
+    Creates WHERE conditions for filtering by numeric ranges, supporting
+    minimum, maximum, or both boundaries.
+
+    Args:
+        filter_item: Dictionary defining the filter configuration including:
+            - columns: List of column expressions to filter
+            - columns_logic: 'or' or 'and' for combining column conditions
+        values: Dictionary containing 'min' and/or 'max' numeric values.
+
+    Returns:
+        A SQLAlchemy boolean expression for the numeric range condition,
+        or None if no valid range is specified.
+    """
+    columns = filter_item.get("columns", [])
     columns_logic = filter_item.get("columns_logic", "or")
     logic_function = {
         "or": or_,
@@ -92,7 +138,25 @@ def number_condition_maker(filter_item: dict, values: dict):
         return logic_function(*[column >= value_min for column in columns])
 
 
-def date_condition_maker(filter_item: dict, values: dict):
+def date_condition_maker(
+    filter_item: dict[str, Any], values: dict[str, datetime]
+) -> ColumnElement[bool] | None:
+    """Build SQL conditions for date range filters.
+
+    Creates WHERE conditions for filtering by date ranges, supporting
+    minimum, maximum, or both boundaries. Handles NULL values gracefully
+    for maximum date filters.
+
+    Args:
+        filter_item: Dictionary defining the filter configuration including:
+            - columns: List of column expressions to filter
+            - columns_logic: 'or' or 'and' for combining column conditions
+        values: Dictionary containing 'min' and/or 'max' datetime values.
+
+    Returns:
+        A SQLAlchemy boolean expression for the date range condition,
+        or None if no valid range is specified.
+    """
     value_min: datetime = values.get("min")
     value_max: datetime = values.get("max")
 
@@ -115,7 +179,22 @@ def date_condition_maker(filter_item: dict, values: dict):
         return logic_function(*[column >= value_min for column in columns])
 
 
-def make_condition(filter_item: dict, values: Any):
+def make_condition(
+    filter_item: dict[str, Any], values: Any
+) -> ColumnElement[bool] | None:
+    """Build SQL WHERE conditions from filter definitions and selected values.
+
+    Routes to the appropriate condition builder based on filter type,
+    creating SQLAlchemy boolean expressions for filtering queries.
+
+    Args:
+        filter_item: Dictionary defining the filter including type and configuration.
+        values: The selected filter values (list for select, dict for ranges).
+
+    Returns:
+        A SQLAlchemy boolean expression representing the filter condition,
+        or None if the filter type is not supported.
+    """
     columns_type = filter_item.get("type", "select")
 
     if columns_type in {"select", "select_array"}:
