@@ -1,3 +1,9 @@
+"""Database utility functions for bulk operations.
+
+Provides upsert (insert or update) functionality for PostgreSQL
+databases with both synchronous and asynchronous support.
+"""
+
 from typing import Any, Dict, List, Type
 
 from sqlalchemy import inspect
@@ -16,14 +22,19 @@ def _prepare_upsert(
     list_of_data: List[Dict[str, Any]],
     model: Type[DeclarativeBase],
 ):
-    """Middle function that prepares the INSERT ... ON CONFLICT DO UPDATE
-    statement for PostgreSQL if possible.
+    """Prepare the INSERT ... ON CONFLICT DO UPDATE statement for PostgreSQL.
 
-    :param list_of_data: A list of dictionaries with data to be inserted/updated.
-    :param model: The SQLAlchemy model class (mapped).
-    :return: Tuple (do_upsert, statement_or_None)
-       - do_upsert (bool) indicates if there's a valid statement to execute.
-       - statement_or_None is the compiled statement or None if no valid upsert is needed.
+    Builds a PostgreSQL-specific upsert statement that inserts new rows or
+    updates existing rows based on primary key conflicts.
+
+    Args:
+        list_of_data: A list of dictionaries with data to be inserted/updated.
+        model: The SQLAlchemy model class (mapped to a table).
+
+    Returns:
+        A tuple (do_upsert, statement_or_None) where:
+            - do_upsert (bool): Indicates if there's a valid statement to execute.
+            - statement_or_None: The compiled statement or None if no valid upsert is needed.
     """
 
     # If there's no data, we can't do anything.
@@ -61,6 +72,26 @@ def upsert_data(
     only_update=False,
     only_insert=False,
 ) -> bool:
+    """Insert or update records in bulk using PostgreSQL upsert semantics.
+
+    Performs bulk insert/update operations with support for PostgreSQL's
+    ON CONFLICT DO UPDATE functionality. Can be configured for insert-only
+    or update-only operations.
+
+    Args:
+        list_of_data: List of dictionaries containing the data to upsert.
+        model: The SQLAlchemy model class representing the target table.
+        db: SQLAlchemy Session for database operations.
+        only_update: If True, only perform updates on existing records.
+        only_insert: If True, only insert new records without updates.
+
+    Returns:
+        True if the operation succeeded, False if there was no data to process.
+
+    Raises:
+        SQLAlchemyError: If database operation fails.
+        IntegrityError: If constraint violations occur.
+    """
     if not list_of_data:
         return False
 
@@ -95,6 +126,26 @@ async def upsert_data_async(
     only_update: bool = False,
     only_insert: bool = False,
 ) -> bool:
+    """Asynchronously insert or update records in bulk using PostgreSQL upsert.
+
+    Performs async bulk insert/update operations with support for PostgreSQL's
+    ON CONFLICT DO UPDATE functionality. Can be configured for insert-only
+    or update-only operations.
+
+    Args:
+        list_of_data: List of dictionaries containing the data to upsert.
+        model: The SQLAlchemy model class representing the target table.
+        db: AsyncSession for asynchronous database operations.
+        only_update: If True, only perform updates on existing records.
+        only_insert: If True, only insert new records without updates.
+
+    Returns:
+        True if the operation succeeded, False if there was no data to process.
+
+    Raises:
+        SQLAlchemyError: If database operation fails.
+        IntegrityError: If constraint violations occur.
+    """
     if not list_of_data:
         return False
 
